#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include "util.h"

/* Esvazia buffer de entrada de stream */
void nflushin(FILE *stream)
{
  int c;

  while ((c = fgetc(stream)) != EOF && c != '\n');
}

/* Mesmo que fgets(), mas retira do buffer o caracter '\n' final que
 * fgets() insere no buffer de entrada. Tambem assegura que buffer interno
 * esvaziado.
 */

char *ngets (char *buf, int maxtam, FILE *stream)
{
  int i;

  buf = fgets(buf, maxtam, stream);
  
  /* elimina '\n' inserido por fgets() */
  if (buf != NULL) {
    if (strlen(buf) != (maxtam - 1)) {
      for (i = strlen(buf); buf[i] != '\n'; i--);
      buf[i] = '\0';
    }
    else
      nflushin(stream);
  }

  return buf;
}

/* Apresenta "prompt" e aguarda string de no maximo "maxsize" caracteres,
 * colocando em um buffer alocado nesta funcao.
 * Se primeiro caracter digitado e'  <ENTER>, retorna um string vazio
 * (strlen == 0).
 * Se houver problemas na alocacao ou na execucao da funcao ngets(), retorna NULL.
 */
char *ngetval(char *prompt, int maxsize)
{

  char *buffer = NULL;

  if (maxsize) {
    fputs(prompt, stdout);
    fflush(stdout);

    if ((buffer = calloc(maxsize, sizeof(char))) != NULL)
      buffer = ngets(buffer, maxsize, stdin);
  }

  return (buffer);

}

/* Dado um string, muda todas as letras para maiuscula */
char *nstrtoupper(char *str)
{
  int i;

  for (i=0; str[i]; ++i)
    str[i] = toupper(str[i]);

  return str;
}


/* Dado um string, muda todas as letras para minuscula */
char *nstrtolower(char *str)
{
  int i;

  for (i=0; str[i]; ++i)
    str[i] = tolower(str[i]);

  return str;
}


/* Capitaliza a string  */
char *nstrcapitalize(char *str)
{
  nstrtolower(str);
  *str = toupper(*str);
  return (str);
}

/* Capitaliza todas as palavras da string  */
char *nstrtitle(char *str)
{
  int i;

  nstrcapitalize(str);
  
  for (i=0; str[i]; ++i)
    {
      if (str[i] == ' ')
	{
	  str[i+1] = toupper(str[i+1]);
	  ++i;
	}
    }

  return (str);
}

